translate.convert.po2xliff.po2xliff

Package translate :: Package convert :: Module po2xliff :: Class po2xliff |
[hide private]
[frames] | no frames]

# Class po2xliff

source code

Instance Methods | [hide private]
convertunit(self, outputstore, inputunit, filename) creates a transunit node | source code
contextlist(self, location) | source code
convertstore(self, inputstore, templatefile=None, **kwargs) converts a .po file to .xlf format | source code